@@ -418,31 +418,6 @@ class TheBlockchainAPIResource:
             raise Exception(response['error_message'])
         return response['transaction_signature']
 
-    def get_candy_machine_config_public_key(
-        self,
-        candy_machine_id: str,
-        network: SolanaNetwork = SolanaNetwork.DEVNET
-    ):
-        """
-        More Info:
-        https://docs.theblockchainapi.com/#tag/Solana-NFT/paths/~1v1~1solana~1nft~1candy_machine~1config/post
-        :param candy_machine_id:
-        :param network:
-        :return:
-        """
-        payload = {
-            "network": network.value,
-            "candy_machine_id": candy_machine_id
-        }
-        response = self._request(
-            payload=payload,
-            endpoint="solana/nft/candy_machine/config",
-            request_method=self.__RequestMethod.POST
-        )
-        if 'error_message' in response:
-            raise Exception(response['error_message'])
-        return response['config_address']
-
     def get_candy_machine_info(
         self,
         candy_machine_id: str,
@@ -551,3 +526,92 @@ class TheBlockchainAPIResource:
         if 'error_message' in response:
             raise Exception(response['error_message'])
         return response
+
+    def get_solana_transaction(
+        self,
+        tx_signature: str,
+        network: SolanaNetwork = SolanaNetwork.DEVNET
+    ):
+        response = self._request(
+            payload={
+                "tx_signature": tx_signature,
+                "network": network.value
+            },
+            endpoint="solana/transaction",
+            request_method=self.__RequestMethod.GET
+        )
+        if 'error_message' in response:
+            raise Exception(response['error_message'])
+        return response
+
+    def get_config_details(
+        self,
+        config_address,
+        network: SolanaNetwork = SolanaNetwork.DEVNET
+    ):
+        payload = {
+            "network": network.value,
+            "config_address": config_address
+        }
+        response = self._request(
+            payload=payload,
+            endpoint="solana/nft/candy_machine/config/info",
+            request_method=self.__RequestMethod.POST
+        )
+        if 'error_message' in response:
+            raise Exception(response['error_message'])
+        return response
+
+    def get_nfts_minted_from_candy_machine(
+        self,
+        candy_machine_id,
+        network: SolanaNetwork = SolanaNetwork.DEVNET
+    ):
+        payload = {
+            "network": network.value,
+            "candy_machine_id": candy_machine_id
+        }
+        response = self._request(
+            payload=payload,
+            endpoint="solana/nft/candy_machine/nfts",
+            request_method=self.__RequestMethod.POST
+        )
+        if 'error_message' in response:
+            raise Exception(response['error_message'])
+        return response
+
+    def get_candy_machine_id_from_nft(
+        self,
+        mint_address,
+        network: SolanaNetwork = SolanaNetwork.DEVNET
+    ):
+        payload = {
+            "network": network.value,
+            "mint_address": mint_address
+        }
+        response = self._request(
+            payload=payload,
+            endpoint="solana/nft/candy_machine_id",
+            request_method=self.__RequestMethod.POST
+        )
+        if 'error_message' in response:
+            raise Exception(response['error_message'])
+        return response
+
+    def get_account_info(
+        self,
+        public_key,
+        network: SolanaNetwork = SolanaNetwork.DEVNET
+    ):
+        payload = {
+            "network": network.value,
+            "public_key": public_key
+        }
+        response = self._request(
+            payload=payload,
+            endpoint="solana/account",
+            request_method=self.__RequestMethod.POST
+        )
+        if 'error_message' in response:
+            raise Exception(response['error_message'])
+        return response
